@@ -2,7 +2,8 @@ from communicationApp import createClient
 def main():
 
   telegram = createClient('telegram', bot_token ='1632387033:AAEgUxJiAwZBRVXwVpocXohQOxZYFhkkR6g')
-  result = telegram.send_photo("https://im.uniqlo.com/style/SDP1779_30012719.jpg")
+  a = {'image_url': "https://im.uniqlo.com/style/SDP1779_30012719.jpg"}
+  result = telegram.send_photo(image_url="https://im.uniqlo.com/style/SDP1779_30012719.jpg")
   print("---------end")
   print(result)
 
